You are viewing a plain text version of this content. The canonical link for it is here.
Posted to xap-commits@incubator.apache.org by jm...@apache.org on 2006/10/17 20:36:16 UTC

svn commit: r465032 - in /incubator/xap/trunk: WebContent/examples/basic/ WebContent/examples/dojo/ WebContent/examples/widgets/ src/xap/bridges/basic/ src/xap/bridges/dojo/ src/xap/bridges/xap/ src/xap/util/

Author: jmargaris
Date: Tue Oct 17 13:36:14 2006
New Revision: 465032

URL: http://svn.apache.org/viewvc?view=rev&rev=465032
Log:
rename of AbstractBlackBoxWidgetBridge

Added:
    incubator/xap/trunk/WebContent/examples/widgets/textFieldEvents.html   (with props)
    incubator/xap/trunk/WebContent/examples/widgets/textFieldEvents.xal   (with props)
    incubator/xap/trunk/src/xap/bridges/basic/AbstractWidgetBridge.js
      - copied, changed from r463854, incubator/xap/trunk/src/xap/bridges/basic/AbstractBlackBoxWidgetBridge.js
Removed:
    incubator/xap/trunk/src/xap/bridges/basic/AbstractBlackBoxWidgetBridge.js
Modified:
    incubator/xap/trunk/WebContent/examples/basic/dom0.html
    incubator/xap/trunk/WebContent/examples/dojo/colorPicker.html
    incubator/xap/trunk/WebContent/examples/dojo/dateAndColorPickers.html
    incubator/xap/trunk/WebContent/examples/dojo/datePicker.html
    incubator/xap/trunk/WebContent/examples/dojo/dojo1.html
    incubator/xap/trunk/WebContent/examples/dojo/dojoExample_0.html
    incubator/xap/trunk/WebContent/examples/dojo/portlet.html
    incubator/xap/trunk/WebContent/examples/widgets/AttributeTester.js
    incubator/xap/trunk/WebContent/examples/widgets/freePanelEvents.xal
    incubator/xap/trunk/WebContent/examples/widgets/index.html
    incubator/xap/trunk/src/xap/bridges/basic/DomNodeBridge.js
    incubator/xap/trunk/src/xap/bridges/dojo/CellBridge.js
    incubator/xap/trunk/src/xap/bridges/dojo/DojoWidgetBridge.js
    incubator/xap/trunk/src/xap/bridges/xap/ButtonBridge.js
    incubator/xap/trunk/src/xap/bridges/xap/CheckboxBridge.js
    incubator/xap/trunk/src/xap/bridges/xap/LabelBridge.js
    incubator/xap/trunk/src/xap/util/allXapClassStrings.txt

Modified: incubator/xap/trunk/WebContent/examples/basic/dom0.html
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/basic/dom0.html?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/WebContent/examples/basic/dom0.html (original)
+++ incubator/xap/trunk/WebContent/examples/basic/dom0.html Tue Oct 17 13:36:14 2006
@@ -24,7 +24,7 @@
     	// look like   	
 		Xap.addDebuggables( 
 						"xap.taghandling.AbstractTagImpl",
-						"xap.bridges.basic.AbstractBlackBoxWidgetBridge",
+						"xap.bridges.basic.AbstractWidgetBridge",
 						"xap.bridges.basic.DomNodeBridge"
 							) ;
     </script>

Modified: incubator/xap/trunk/WebContent/examples/dojo/colorPicker.html
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/dojo/colorPicker.html?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/WebContent/examples/dojo/colorPicker.html (original)
+++ incubator/xap/trunk/WebContent/examples/dojo/colorPicker.html Tue Oct 17 13:36:14 2006
@@ -1,7 +1,7 @@
 <html>
 <head>
     <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
-    <title>A Dojo "ColorPalette" wrapped by an AbstractBlackBoxWidgetBridge subclass.</title>
+    <title>A Dojo "ColorPalette" wrapped by an AbstractWidgetBridge subclass.</title>
 
 	<style type="text/css">
       <!--
@@ -27,7 +27,7 @@
 		Xap.addDebuggables( 
 						"xap.session.ClientSession",
 						"xap.taghandling.AbstractTagImpl",
-						"xap.bridges.basic.AbstractBlackBoxWidgetBridge",
+						"xap.bridges.basic.AbstractWidgetBridge",
 						"xap.bridges.dojo.DojoWidgetBridge",
 						"xap.bridges.dojo.DojoColorPaletteBridge"						
 							) ;
@@ -59,7 +59,7 @@
   
  <body onload="divv=document.getElementById('dp') ;dojo.widget.createWidget('ColorPalette',{widgetId:'dp'},divv);Xap.createAllPredefinedSessions();if(document.showXapStatus){document.showXapStatus('ColorPicker');}; ">
 
-	<h1>A Dojo "ColorPalette" wrapped by an AbstractBlackBoxWidgetBridge subclass, managed by a xaplet in that cell.</h1>
+	<h1>A Dojo "ColorPalette" wrapped by an AbstractWidgetBridge subclass, managed by a xaplet in that cell.</h1>
 	
 	<table id="bigtable" border="4px" borderColor="#8866AA" width="80%" height="80%"
 		style="left:10%;top:10%"

Modified: incubator/xap/trunk/WebContent/examples/dojo/dateAndColorPickers.html
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/dojo/dateAndColorPickers.html?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/WebContent/examples/dojo/dateAndColorPickers.html (original)
+++ incubator/xap/trunk/WebContent/examples/dojo/dateAndColorPickers.html Tue Oct 17 13:36:14 2006
@@ -27,7 +27,7 @@
 		Xap.addDebuggables( 
 						"xap.session.ClientSession",
 						"xap.taghandling.AbstractTagImpl",
-						"xap.bridges.basic.AbstractBlackBoxWidgetBridge",
+						"xap.bridges.basic.AbstractWidgetBridge",
 						"xap.bridges.dojo.DojoWidgetBridge",
 						"xap.bridges.dojo.DojoDatePickerBridge",
 						"xap.bridges.dojo.DojoColorPaletteBridge",						

Modified: incubator/xap/trunk/WebContent/examples/dojo/datePicker.html
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/dojo/datePicker.html?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/WebContent/examples/dojo/datePicker.html (original)
+++ incubator/xap/trunk/WebContent/examples/dojo/datePicker.html Tue Oct 17 13:36:14 2006
@@ -1,7 +1,7 @@
 <html>
 <head>
     <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
-    <title>A Dojo "DatePicker" wrapped by an AbstractBlackBoxWidgetBridge subclass.</title>
+    <title>A Dojo "DatePicker" wrapped by an AbstractWidgetBridge subclass.</title>
 
 
 	<!-- Keep dojo from trying to scan this whole page for dojoType'd tags: -->
@@ -22,7 +22,7 @@
 		Xap.addDebuggables( 
 						"xap.session.ClientSession",
 						"xap.taghandling.AbstractTagImpl",
-						"xap.bridges.basic.AbstractBlackBoxWidgetBridge",
+						"xap.bridges.basic.AbstractWidgetBridge",
 						"xap.bridges.dojo.DojoWidgetBridge",
 						"xap.bridges.dojo.DojoDatePickerBridge",
 						"xap.session.EventHandler"					
@@ -58,7 +58,7 @@
  </head>
   
  <body onload="divv=document.getElementById('dp') ;dojo.widget.createWidget('datepicker',{widgetId:'dp'},divv);Xap.createAllPredefinedSessions();if(document.showXapStatus){document.showXapStatus('DatePicker');}; ">
-	<h1>A Dojo "DatePicker" wrapped by an AbstractBlackBoxWidgetBridge subclass, managed by a xaplet in a different cell.</h1>
+	<h1>A Dojo "DatePicker" wrapped by an AbstractWidgetBridge subclass, managed by a xaplet in a different cell.</h1>
 	
 	<table id="bigtable" border="4px" borderColor="#8866AA" width="80%" height="80%"
 		style="left:10%;top:10%"

Modified: incubator/xap/trunk/WebContent/examples/dojo/dojo1.html
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/dojo/dojo1.html?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/WebContent/examples/dojo/dojo1.html (original)
+++ incubator/xap/trunk/WebContent/examples/dojo/dojo1.html Tue Oct 17 13:36:14 2006
@@ -26,7 +26,7 @@
     	// look like   	
 		Xap.addDebuggables( 
 						"xap.taghandling.AbstractTagImpl",
-						"xap.bridges.basic.AbstractBlackBoxWidgetBridge",						
+						"xap.bridges.basic.AbstractWidgetBridge",						
 						"xap.bridges.dojo.DojoWidgetBridge",		
 						"xap.bridges.dojo.DojoButtonBridge"
 							) ;

Modified: incubator/xap/trunk/WebContent/examples/dojo/dojoExample_0.html
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/dojo/dojoExample_0.html?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/WebContent/examples/dojo/dojoExample_0.html (original)
+++ incubator/xap/trunk/WebContent/examples/dojo/dojoExample_0.html Tue Oct 17 13:36:14 2006
@@ -27,7 +27,7 @@
 		Xap.addDebuggables( 
 						"xap.session.ClientSession",
 						"xap.taghandling.AbstractTagImpl",
-						"xap.bridges.basic.AbstractBlackBoxWidgetBridge",
+						"xap.bridges.basic.AbstractWidgetBridge",
 						"xap.bridges.dojo.DojoWidgetBridge",
 						"xap.bridges.dojo.DojoButtonBridge",						
 						"xap.bridges.dojo.DojoFloatingPaneBridge",

Modified: incubator/xap/trunk/WebContent/examples/dojo/portlet.html
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/dojo/portlet.html?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/WebContent/examples/dojo/portlet.html (original)
+++ incubator/xap/trunk/WebContent/examples/dojo/portlet.html Tue Oct 17 13:36:14 2006
@@ -27,7 +27,7 @@
 		Xap.addDebuggables( 
 						"xap.session.ClientSession",
 						"xap.taghandling.AbstractTagImpl",
-						"xap.bridges.basic.AbstractBlackBoxWidgetBridge",
+						"xap.bridges.basic.AbstractWidgetBridge",
 						"xap.bridges.dojo.DojoWidgetBridge",
 						"xap.bridges.dojo.DojoColorPaletteBridge"						
 							) ;

Modified: incubator/xap/trunk/WebContent/examples/widgets/AttributeTester.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/widgets/AttributeTester.js?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/WebContent/examples/widgets/AttributeTester.js (original)
+++ incubator/xap/trunk/WebContent/examples/widgets/AttributeTester.js Tue Oct 17 13:36:14 2006
@@ -21,47 +21,6 @@
 	this.log(event.toString());
 }
 
-//IMPORTANT can remove this now probably
-// Don't want to trigger an additional onEdit by popping up
-// an alert() box, which would make the textfield lose focus---so write it here
-AttributeTester.prototype.reportTextFieldEventWithoutAlert = function(event){
-	var evt = event.originalEvent ;
-	var code ;
-	if (evt.keyCode){
-		// moz
-		code = evt.keyCode;
-	}	else if (	evt.which){
-		code = evt.which;
-	}
-	
-	
-	var pressed = "";
-	if( code<65 || code>91){
-		pressed = "<non-alphabetic>"
-	} else {
-		if(!evt.shiftKey){
-			code += 32 ;
-		}
-		pressed = "'"+String.fromCharCode(code) +"'" ;
-	}
-	
-	var sourceElement = event.source ;
-	
-	var statusText =  (""+event).replace(/[\r\n]/g,";") ;
-
-	var statusLineElement = sourceElement.getOwnerDocument().getElementById("status") ;
-	
-	if( !statusLineElement ){
-		return ;
-	}	
-	var statusLineHandler 
-		= event.session.getUiDocumentHandler().getHandlerForElement( statusLineElement );				
-	statusLineHandler.setTextAttribute( "[" +code+":"+ pressed+"]:   " +statusText ) ;
-
-}
-
-
-
 AttributeTester.prototype.log = function(text){
 	if (!this._logDiv){
 		var l = document.createElement('div');
@@ -82,6 +41,9 @@
 	text = text.replace(/&/g, '&amp;').replace(/</g, '&lt;').replace(/>/g, '&gt;');
 	text = text.replace(/\n/g,'<br>');
 	this._logDiv.innerHTML = this._logDiv.innerHTML + "<br><br>" + text;
+	if (this._logDiv.innerHTML.length>5000){
+      	this._logDiv.innerHTML = this._logDiv.innerHTML.substring(this._logDiv.innerHTML.length-5000);
+	}
 	this._logDiv.scrollTop = this._logDiv.scrollHeight;
 	
 }

Modified: incubator/xap/trunk/WebContent/examples/widgets/freePanelEvents.xal
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/widgets/freePanelEvents.xal?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/WebContent/examples/widgets/freePanelEvents.xal (original)
+++ incubator/xap/trunk/WebContent/examples/widgets/freePanelEvents.xal Tue Oct 17 13:36:14 2006
@@ -16,7 +16,7 @@
 		id="testComponent" orientation="horizontal"
 			onActiveLost="mco:attributeSetter.reportEvent(event)"
 			onActiveGained="mco:attributeSetter.reportEvent(event)"
-			onDblClick="mco:attributeSetter.reportEvent(event)"
+			onDoubleClick="mco:attributeSetter.reportEvent(event)"
 			onMouseDown="mco:attributeSetter.reportEvent(event)"
 			onMouseUp="mco:attributeSetter.reportEvent(event)"
 			onKeyDown="mco:attributeSetter.reportEvent(event)"

Modified: incubator/xap/trunk/WebContent/examples/widgets/index.html
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/widgets/index.html?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/WebContent/examples/widgets/index.html (original)
+++ incubator/xap/trunk/WebContent/examples/widgets/index.html Tue Oct 17 13:36:14 2006
@@ -27,6 +27,7 @@
 <h2>Event Tests</h2>
 <ul>
 <li><a href="freePanelEvents.html">&lt;freePanel&gt;</a></li>
+<li><a href="textFieldEvents.html">&lt;textField&gt;</a></li>
 </ul>
 
 <br>

Added: incubator/xap/trunk/WebContent/examples/widgets/textFieldEvents.html
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/widgets/textFieldEvents.html?view=auto&rev=465032
==============================================================================
--- incubator/xap/trunk/WebContent/examples/widgets/textFieldEvents.html (added)
+++ incubator/xap/trunk/WebContent/examples/widgets/textFieldEvents.html Tue Oct 17 13:36:14 2006
@@ -0,0 +1,29 @@
+<!DOCTYPE HTML PUBLIC "-//W3C//DTD HTML 4.01 Transitional//EN"
+"http://www.w3.org/TR/html4/loose.dtd">
+<html>
+<head>
+    <meta http-equiv="Content-Type" content="text/html; charset=UTF-8">
+    <title>Button</title>
+
+	<style type="text/css">
+      <!--
+          @import url(../../css/xapDefault.css);
+      -->
+    </style>
+    
+	<!-- Keep dojo from trying to scan this whole page for dojoType'd tags: -->
+	<script type="text/javascript">
+		djConfig = {
+			parseWidgets: false
+		};
+	</script>    
+	
+	<script language="JavaScript" type="text/javascript" src="../../xapcore.js"></script>
+   <script language="JavaScript" type="text/javascript" src="AttributeTester.js"></script>
+    
+ </head>
+  
+ <body  onload="Xap.createAllPredefinedSessions();">
+	<div xapId="ButtonExample" xapSrc="textFieldEvents.xal" xapToolkit="dojo" xapContext="../../"></div>
+</body>
+</html>

Propchange: incubator/xap/trunk/WebContent/examples/widgets/textFieldEvents.html
------------------------------------------------------------------------------
    svn:eol-style = native

Added: incubator/xap/trunk/WebContent/examples/widgets/textFieldEvents.xal
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/WebContent/examples/widgets/textFieldEvents.xal?view=auto&rev=465032
==============================================================================
--- incubator/xap/trunk/WebContent/examples/widgets/textFieldEvents.xal (added)
+++ incubator/xap/trunk/WebContent/examples/widgets/textFieldEvents.xal Tue Oct 17 13:36:14 2006
@@ -0,0 +1,29 @@
+<xal xmlns="http://www.openxal.org/xal" xmlns:xal="http://www.openxal.org/xal"> 
+
+
+	<mco:mco 
+		xmlns:mco="http://www.openxal.org/mco" 
+		id="attributeSetter" 
+		src="AttributeTester"
+	/>
+
+
+
+	<xm:modifications xmlns:xm="http://www.openxal.org/xmodify">
+	<xm:append select="/xal">
+	
+		<xal:textField width="200px" focused="true"
+		id="testComponent" orientation="horizontal"
+			onActiveLost="mco:attributeSetter.reportEvent(event)"
+			onActiveGained="mco:attributeSetter.reportEvent(event)"
+			onDoubleClick="mco:attributeSetter.reportEvent(event)"
+			onMouseDown="mco:attributeSetter.reportEvent(event)"
+			onMouseUp="mco:attributeSetter.reportEvent(event)"
+			onKeyDown="mco:attributeSetter.reportEvent(event)"
+			onKeyUp="mco:attributeSetter.reportEvent(event)"
+			onKeyPress="mco:attributeSetter.reportEvent(event)"
+		/>
+
+	</xm:append> 	  		
+  	</xm:modifications>
+</xal>

Propchange: incubator/xap/trunk/WebContent/examples/widgets/textFieldEvents.xal
------------------------------------------------------------------------------
    svn:eol-style = native

Copied: incubator/xap/trunk/src/xap/bridges/basic/AbstractWidgetBridge.js (from r463854, incubator/xap/trunk/src/xap/bridges/basic/AbstractBlackBoxWidgetBridge.js)
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/basic/AbstractWidgetBridge.js?view=diff&rev=465032&p1=incubator/xap/trunk/src/xap/bridges/basic/AbstractBlackBoxWidgetBridge.js&r1=463854&p2=incubator/xap/trunk/src/xap/bridges/basic/AbstractWidgetBridge.js&r2=465032
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/basic/AbstractBlackBoxWidgetBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/basic/AbstractWidgetBridge.js Tue Oct 17 13:36:14 2006
@@ -15,7 +15,7 @@
  *
  */
  
-Xap.provide("xap.bridges.basic.AbstractBlackBoxWidgetBridge"); 
+Xap.provide("xap.bridges.basic.AbstractWidgetBridge"); 
 
 Xap.require("xap.util.Utils");
 Xap.require("xap.util.Exception");
@@ -23,6 +23,7 @@
 Xap.require("xap.taghandling.AbstractTagImpl") ;
 Xap.require("dojo.widget.Tooltip") ;
 Xap.require("dojo.event.*") ;
+Xap.require("xap.session.ClientEvent");
  
 /**
  *  @fileoverview
@@ -38,12 +39,12 @@
  * need to create one (am currently using getNodeForChildren() for parent and container, a bad idea.)
  *.2.) Rename private methods with leading underscores "_".
  * 3.) Maybe find a better name for this class; the "BlackBox" is there to make a point about avoiding
- * making direct calls to peer methods from the bridge, but having been made it might be a bit much. 
+ * making direct calls to peer methods from the bridge, but having been made it might be a bit much. 
 */
  
  
  /**
- * Creates a xap.bridges.basic.AbstractBlackBoxWidgetBridge.
+ * Creates a xap.bridges.basic.AbstractWidgetBridge.
  * 
  *  A subclass of <code>xap.taghandling.AbstractTagImpl</code>
  *  intended as an abstract<code> </code>superclass for the
@@ -64,12 +65,12 @@
  * @see xap.session.ClientSession#createInitialDocument
  * @see xap.bridges.dojo.DojoWidgetBridge 
  */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge =  function() {
+xap.bridges.basic.AbstractWidgetBridge =  function() {
 	xap.taghandling.AbstractTagImpl.call( this );
 }
 
 
-Xap.setupClassAsSubclassOf("xap.bridges.basic.AbstractBlackBoxWidgetBridge","xap.taghandling.AbstractTagImpl");
+Xap.setupClassAsSubclassOf("xap.bridges.basic.AbstractWidgetBridge","xap.taghandling.AbstractTagImpl");
 
 
 
@@ -89,7 +90,7 @@
  * @see xap.session.ClientSession#_createInitialDocument
  * 
 **/ 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.init = function() {
+xap.bridges.basic.AbstractWidgetBridge.prototype.init = function() {
 	this.createPeer();
 	this.parseInitialAttributes( this.getElement() );
 	this.parseInitialChildren( this.getElement() );
@@ -104,22 +105,22 @@
  *  Reserved word that will equal the result of applying the <code>typeof</code> operator 
  *  on a function object.
 **/ 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.FUNCTION="function" ; 
+xap.bridges.basic.AbstractWidgetBridge.FUNCTION="function" ; 
 
 /**
  *  @private
  *  @static
  *  String marking the beginning of an event method---not perfect, but a 90/10 rule applies.
 **/ 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.ON="on" ;
+xap.bridges.basic.AbstractWidgetBridge.ON="on" ;
 
 /**
  * @static
  *   Determines if an object, typically a member on another object,  is a function.
 **/ 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.s_IsFunction = function(aMember){
+xap.bridges.basic.AbstractWidgetBridge.s_IsFunction = function(aMember){
 	var typ =  typeof aMember ;
-	var eqq =  (typ== xap.bridges.basic.AbstractBlackBoxWidgetBridge.FUNCTION) ;
+	var eqq =  (typ== xap.bridges.basic.AbstractWidgetBridge.FUNCTION) ;
 	return eqq ;
 }
 	
@@ -193,7 +194,7 @@
  *   @throws xap.util.Exception if the peer is unobtainable, or if the bridge subclass
  *   is missing, or if the supposed parent XapElement or bridge is not one of those.
 **/ 	
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.createPeer = function() {
+xap.bridges.basic.AbstractWidgetBridge.prototype.createPeer = function() {
 	// Implemented by subclasses---here, we don't care how they get it:  with a simple
 	// constructor, via a database call, using a JSON-encoded object over the fibre,
 	// or stolen from a fruit-cart:
@@ -221,7 +222,7 @@
   *  Default behaviour: most widgets are not containers, so they have
   *  none such.  Lowest common denominator.
  **/
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.getNodeForChildren =  function(){
+xap.bridges.basic.AbstractWidgetBridge.prototype.getNodeForChildren =  function(){
 	return null;
 }
 
@@ -230,7 +231,7 @@
  * for example the wrapping div. We will set basic attributes
  * like color on this div in the absence of better setter methods.
  */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.getRootDomNode =  function(){
+xap.bridges.basic.AbstractWidgetBridge.prototype.getRootDomNode =  function(){
 	return null;
 }
 
@@ -242,7 +243,7 @@
  *   Closure to create a default event-handling function for one of the peer's---is there still a problem 
  *   (memory leak) with this in IE?
 **/ 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.getOnXFunction = function(str){
+xap.bridges.basic.AbstractWidgetBridge.prototype.getOnXFunction = function(str){
 	return function(anEvent){
 		        var clientEvent = new xap.session.ClientEvent(this.getElement(),this.getSession());
 	            clientEvent.eventObject = anEvent ;
@@ -250,20 +251,20 @@
 		 	} ;
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.childAdded = function( e ) {
+xap.bridges.basic.AbstractWidgetBridge.prototype.childAdded = function( e ) {
 	var childElement = e.getChange();
 	var childHandler = this.getUiContentHandler().getHandlerForElement( childElement );
 	this.addChild(childHandler, e.getIndex());
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.onChildRemoved = function (e) {
+xap.bridges.basic.AbstractWidgetBridge.prototype.onChildRemoved = function (e) {
    var childElement = e.getChange();
 	var childHandler = this.getUiContentHandler().getHandlerForElement( childElement );
 	this.removeChild(childHandler);
 	xap.taghandling.AbstractTagImpl.prototype.onChildRemoved.call( this, e );
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.addChild = function(childHandler, index){
+xap.bridges.basic.AbstractWidgetBridge.prototype.addChild = function(childHandler, index){
 	if (this.getNodeForChildren && this.getNodeForChildren() && 
 		childHandler.getRootDomNode && childHandler.getRootDomNode()){
 		this.getNodeForChildren().appendChild(childHandler.getRootDomNode());
@@ -278,7 +279,7 @@
 	}
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.removeChild = function(childHandler, index){
+xap.bridges.basic.AbstractWidgetBridge.prototype.removeChild = function(childHandler, index){
 	if (this.getNodeForChildren && this.getNodeForChildren() &&
 	childHandler.getRootDomNode && childHandler.getRootDomNode()){
 		this.getNodeForChildren().removeChild(childHandler.getRootDomNode());
@@ -290,17 +291,17 @@
  *	Default behavior:  mirror all "onXXX" methods on the bridge using <code>fireEvent</code> calls
  *   ---we can change this in subclasses if we don't like it.  
 **/ 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.findPeerEvents= function() {
+xap.bridges.basic.AbstractWidgetBridge.prototype.findPeerEvents= function() {
 	if(! this.eventTriggers ){
 		var triggerMap = new Object() ;
 		// Let's transfer all the "onXXX" methods over to the bridge---first find
 		// them, then use a closure to create the new function:
 		for(var methodName in this._peer){
 			var member = this._peer[methodName] ;
-			if( !xap.bridges.basic.AbstractBlackBoxWidgetBridge.s_IsFunction(member) ){
+			if( !xap.bridges.basic.AbstractWidgetBridge.s_IsFunction(member) ){
 				continue ;
 			}
-			if(  methodName.substring(0,2)==xap.bridges.basic.AbstractBlackBoxWidgetBridge.ON){
+			if(  methodName.substring(0,2)==xap.bridges.basic.AbstractWidgetBridge.ON){
 			// By default, "<bridge>.onFoo" maps to "<peer>.onFoo", but this could 
 			// change, so allow for that:
 				triggerMap[methodName] = { src: this._peer, methodName: methodName }  ;
@@ -318,7 +319,7 @@
  * lay out the location for a component.
  *
 **/ 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.getSpecifiedDisplayNode = function(){
+xap.bridges.basic.AbstractWidgetBridge.prototype.getSpecifiedDisplayNode = function(){
 	// What will the id of the node to which we'll attach this widget be?
 	var xapDisplayId = this.getElement().getAttribute("displayerId");
 	return document.getElementById(xapDisplayId);
@@ -332,7 +333,7 @@
  * toolkit or widget level.
  * @param event{AttributeChangeEvent}
 **/
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.attributeSet = function( event ) { 
+xap.bridges.basic.AbstractWidgetBridge.prototype.attributeSet = function( event ) { 
 	var name = event.getName(); 
 	var value = event.getNewValue(); 
 	
@@ -373,7 +374,7 @@
  * preference a particular, generally widget-specific method,
  * to our own "onCommand".
 **/ 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.autoAttachBridgeEventsToPeerEvents = function(){
+xap.bridges.basic.AbstractWidgetBridge.prototype.autoAttachBridgeEventsToPeerEvents = function(){
 
 	// O.K., <code>this</code> is an object we can use as a  bridge---go on:		
 	var triggers = this.findPeerEvents() ;
@@ -403,7 +404,7 @@
 
 
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.getAllowedAttributes = function(){
+xap.bridges.basic.AbstractWidgetBridge.prototype.getAllowedAttributes = function(){
 	if (this.constructor._allowedAttributes){
 		return this.constructor._allowedAttributes;
 	}
@@ -425,7 +426,7 @@
  * Set this xaplet's location in the HTML DOM:
  * @param parentPeerDomNode---default location.... 
 **/ 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setHtmlDomLocation = function(parentPeerDomNode){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setHtmlDomLocation = function(parentPeerDomNode){
 	// By default, component goes within parent's HTML DOM node;
 	//---but can specify another one as below:
 	// using a decision (getSpecifiedDisplayNode()) implemented in
@@ -453,11 +454,11 @@
  * @return {Object} the function the above maps-to, according to 
  * <center><code>  foo &rarr;  bridgeClass.prototype.setFooAttribute  </code></center>
 **/
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.getSetterFunctionForAttribute  = function( name ) {
+xap.bridges.basic.AbstractWidgetBridge.prototype.getSetterFunctionForAttribute  = function( name ) {
 	return this._getNameToSetterMap() [name] ;
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.initialiseAttributeMaps = function(){
+xap.bridges.basic.AbstractWidgetBridge.prototype.initialiseAttributeMaps = function(){
 	// Initialise the default name-to[gs]etter map used under attributeSet:
 	
 	//TODO is this once per object? or once per class?
@@ -474,7 +475,7 @@
 	}	
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.getNewAllowedAttributes = function(){
+xap.bridges.basic.AbstractWidgetBridge.prototype.getNewAllowedAttributes = function(){
 	return ["x","y","width","height","backgroundColor",
 		"borderWidth","borderColor","borderStyle","margin",
 		"padding","color","textDecoration","fontFamily",
@@ -488,97 +489,97 @@
  * dictionary itself is held on the class (constructor), since it should be
  * the same for all instances.
 **/ 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype._getNameToSetterMap = function(){
+xap.bridges.basic.AbstractWidgetBridge.prototype._getNameToSetterMap = function(){
 	return this.constructor._nameToSetterMap ;
 }
 
 /** XML attribute set method for "x" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setXAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setXAttribute = function(value){
 	this.getRootDomNode().style.left = value ;
 }
 
 /** XML attribute set method for "y" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setYAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setYAttribute = function(value){
 	this.getRootDomNode().style.top = value ;
 }
 
 /** XML attribute set method for "width" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setWidthAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setWidthAttribute = function(value){
 	this.getRootDomNode().style.width = value ;
 }
 
 /** XML attribute set method for "height" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setHeightAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setHeightAttribute = function(value){
 	this.getRootDomNode().style.height = value ;
 }
 
 
 /** XML attribute set method for "backgroundColor" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setBackgroundColorAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setBackgroundColorAttribute = function(value){
 	this.getRootDomNode().style.backgroundColor = value ;
 }
 
 /** XML attribute set method for "borderWidth" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setBorderWidthAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setBorderWidthAttribute = function(value){
 	this.getRootDomNode().style.borderWidth = value ;
 }
 
 /** XML attribute set method for "borderStyle" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setBorderStyleAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setBorderStyleAttribute = function(value){
 	this.getRootDomNode().style.borderStyle = value ;
 }
 
 /** XML attribute set method for "borderColor" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setBorderColorAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setBorderColorAttribute = function(value){
 	this.getRootDomNode().style.borderColor = value ;
 }
 
 /** XML attribute set method for "color" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setColorAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setColorAttribute = function(value){
 	this.getRootDomNode().style.color = value ;
 }
 
 /** XML attribute set method for "fontFamily" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setFontFamilyAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setFontFamilyAttribute = function(value){
 	this.getRootDomNode().style.fontFamily = value ;
 }
 
 /** XML attribute set method for "fontSize" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setFontSizeAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setFontSizeAttribute = function(value){
 	this.getRootDomNode().style.fontSize = value ;
 }
 
 /** XML attribute set method for "fontStyle" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setFontStyleAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setFontStyleAttribute = function(value){
 	this.getRootDomNode().style.fontStyle = value ;
 }
 
 /** XML attribute set method for "fontWeight" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setFontWeightAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setFontWeightAttribute = function(value){
 	this.getRootDomNode().style.fontWeight = value ;
 }
 
 /** XML attribute set method for "margin" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setMarginAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setMarginAttribute = function(value){
 	this.getRootDomNode().style.margin = value ;
 }
 
 /** XML attribute set method for "textDecoration" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setTextDecorationAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setTextDecorationAttribute = function(value){
 	this.getRootDomNode().style.textDecoration = value ;
 }
 
 /** XML attribute set method for "padding" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setPaddingAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setPaddingAttribute = function(value){
 	this.getRootDomNode().style.padding = value ;
 }
 
 /** XML attribute set method for "textAlign" */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setTextAlignAttribute = function(value){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setTextAlignAttribute = function(value){
 	this.getRootDomNode().style.textAlign = value ;
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setPopupAttribute = function(popupId){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setPopupAttribute = function(popupId){
 	//TODO fire onContextMenu event and let them consume it?
 	//TODO if they have OLD popup need to unregister it!!!
 	popupId = popupId.substring(1);
@@ -593,7 +594,7 @@
 }
 
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setTooltipAttribute = function( text ){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setTooltipAttribute = function( text ){
 	//TODO should this accept a popup reference like #myTip ?
 	//TODO if they have OLD tooltip need to unregister it!!!
 	
@@ -610,20 +611,24 @@
 	dojo.event.connect(tooltip.connectNode, "onmouseover", tooltip, "onMouseOver");
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.setFocusedAttribute = function( text ){
+xap.bridges.basic.AbstractWidgetBridge.prototype.setFocusedAttribute = function( text ){
 	if (text=="true"){
 		this._requestFocus();
 		
 		//have to schedule it because focus can't take place
 		//until DOM is all set and doc is fully loaded
 		//so thing above won't always work
-		dojo.lang.setTimeout(this,_requestFocus,0);	
+		dojo.lang.setTimeout(this,"_requestFocus",0);	
 	}
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype._requestFocus = function(){
+xap.bridges.basic.AbstractWidgetBridge.prototype._requestFocus = function(){
 	var rootNode = this.getRootDomNode();
 	if (rootNode && rootNode.focus){	
+		//we don't want to fire an event if they set focus
+		//programatically so remember that we are setting it
+		//IMPORTANT timing problems here if it is already a part of DOM?
+		this._settingFocus = true;
 		rootNode.focus();
 	}
 }
@@ -637,38 +642,68 @@
  * 
  * 
  */
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.onFocus = function(e){
-	this.fireEvent("onActiveGained");
+xap.bridges.basic.AbstractWidgetBridge.prototype.onFocus = function(e){
+	if (!this._settingFocus){
+		this.fireEvent("onActiveGained");
+	}
+	else{
+		delete this._settingFocus;
+	}
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.onBlur = function(e){
+xap.bridges.basic.AbstractWidgetBridge.prototype.onBlur = function(e){
 	this.fireEvent("onActiveLost");
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.onDblClick = function(e){
-	this.fireEvent("onDblClick");
+xap.bridges.basic.AbstractWidgetBridge.prototype.onDblClick = function(e){
+	this.fireMouseEvent("onDoubleClick",e);
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.onMouseDown = function(e){
-	this.fireEvent("onMouseDown");
+xap.bridges.basic.AbstractWidgetBridge.prototype.onMouseDown = function(e){
+	this.fireMouseEvent("onMouseDown",e);
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.onMouseUp = function(e){
-	this.fireEvent("onMouseUp");
+xap.bridges.basic.AbstractWidgetBridge.prototype.onMouseUp = function(e){
+	this.fireMouseEvent("onMouseUp",e);
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.onKeyDown = function(e){
-	this.fireEvent("onKeyDown");
+xap.bridges.basic.AbstractWidgetBridge.prototype.onKeyDown = function(e){
+	this.fireKeyEvent("onKeyDown",e);
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.onKeyUp = function(e){
-	this.fireEvent("onKeyUp");
+xap.bridges.basic.AbstractWidgetBridge.prototype.onKeyUp = function(e){
+	this.fireKeyEvent("onKeyUp",e);
 }
 
-xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.onKeyPress = function(e){
-	this.fireEvent("onKeyPress");
+xap.bridges.basic.AbstractWidgetBridge.prototype.onKeyPress = function(e){
+	this.fireKeyEvent("onKeyPress",e);
 }
 
-		
-		
 
+xap.bridges.basic.AbstractWidgetBridge.prototype.fireMouseEvent = function( eventName, htmlEvent){
+	var clientEvent = new xap.session.ClientEvent(this.getElement(),this.getSession());
+	clientEvent.htmlEvent = htmlEvent;
+	
+	//relative to current component, this seems right in IE and moz
+	clientEvent.clickX = htmlEvent.layerX;
+	clientEvent.clickY = htmlEvent.layerY;
+	clientEvent.buttonNumber = htmlEvent.button;
+	this.fireEvent(eventName,null,null,clientEvent);
+	//IMPORTANT button number is 0-2 based, not 1-3?
+	//depends on browser, need to fix this up...
+	//IMPORTANT mods, consumed, cancel?
+}
+
+xap.bridges.basic.AbstractWidgetBridge.prototype.fireKeyEvent = function( eventName, htmlEvent){
+	var clientEvent = new xap.session.ClientEvent(this.getElement(),this.getSession());
+	clientEvent.htmlEvent = htmlEvent;
+	
+	var code;
+	if (htmlEvent.keyCode) code = htmlEvent.keyCode;
+	else if (htmlEvent.which) code = htmlEvent.which;
+	var character = String.fromCharCode(code);
+	clientEvent.keyCode = code;
+	clientEvent.keyChar = character;
+	this.fireEvent(eventName,null,null,clientEvent);
+	//IMPORTANT mods, consumed, cancel?
+}
\ No newline at end of file

Modified: incubator/xap/trunk/src/xap/bridges/basic/DomNodeBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/basic/DomNodeBridge.js?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/dojo/CellBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/dojo/CellBridge.js Tue Oct 17 13:36:14 2006
@@ -16,13 +16,13 @@
  */
 
 Xap.provide("xap.bridges.dojo.CellBridge"); 
-Xap.require("xap.bridges.basic.AbstractBlackBoxWidgetBridge");
+Xap.require("xap.bridges.basic.AbstractWidgetBridge");
 
 xap.bridges.dojo.CellBridge = function() {
-	xap.bridges.basic.AbstractBlackBoxWidgetBridge.call(this);
+	xap.bridges.basic.AbstractWidgetBridge.call(this);
 }
 
-Xap.setupClassAsSubclassOf("xap.bridges.dojo.CellBridge", "xap.bridges.basic.AbstractBlackBoxWidgetBridge");
+Xap.setupClassAsSubclassOf("xap.bridges.dojo.CellBridge", "xap.bridges.basic.AbstractWidgetBridge");
 
 
 

Modified: incubator/xap/trunk/src/xap/bridges/dojo/DojoWidgetBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/dojo/DojoWidgetBridge.js?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/dojo/DojoWidgetBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/dojo/DojoWidgetBridge.js Tue Oct 17 13:36:14 2006
@@ -16,7 +16,7 @@
  */
 
 Xap.provide("xap.bridges.dojo.DojoWidgetBridge");  
-Xap.require("xap.bridges.basic.AbstractBlackBoxWidgetBridge"); 
+Xap.require("xap.bridges.basic.AbstractWidgetBridge"); 
 // Auto-added---o.k.?
 Xap.require("xap.util.Exception");
 Xap.require("dojo.widget.HtmlWidget");
@@ -47,12 +47,12 @@
  * @author mturyn
  */
 xap.bridges.dojo.DojoWidgetBridge =  function() {
-	xap.bridges.basic.AbstractBlackBoxWidgetBridge.call( this );
+	xap.bridges.basic.AbstractWidgetBridge.call( this );
 }
 
 Xap.setupClassAsSubclassOf(
 	"xap.bridges.dojo.DojoWidgetBridge",
-	"xap.bridges.basic.AbstractBlackBoxWidgetBridge"
+	"xap.bridges.basic.AbstractWidgetBridge"
 );
 
 
@@ -276,7 +276,7 @@
 		}
 	}	
 
-	xap.bridges.basic.AbstractBlackBoxWidgetBridge.prototype.init.call(this);
+	xap.bridges.basic.AbstractWidgetBridge.prototype.init.call(this);
 
 	if( this.getPeer().show){
 		this.getPeer().show();

Modified: incubator/xap/trunk/src/xap/bridges/xap/ButtonBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/xap/ButtonBridge.js?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/xap/ButtonBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/xap/ButtonBridge.js Tue Oct 17 13:36:14 2006
@@ -16,14 +16,14 @@
  */
 
 Xap.provide("xap.bridges.xap.ButtonBridge"); 
-Xap.require("xap.bridges.basic.AbstractBlackBoxWidgetBridge");
+Xap.require("xap.bridges.basic.AbstractWidgetBridge");
 Xap.require("xap.widgets.Button");
 
 xap.bridges.xap.ButtonBridge = function() {
-	xap.bridges.basic.AbstractBlackBoxWidgetBridge.call(this);
+	xap.bridges.basic.AbstractWidgetBridge.call(this);
 }
 
-Xap.setupClassAsSubclassOf("xap.bridges.xap.ButtonBridge", "xap.bridges.basic.AbstractBlackBoxWidgetBridge");
+Xap.setupClassAsSubclassOf("xap.bridges.xap.ButtonBridge", "xap.bridges.basic.AbstractWidgetBridge");
 
 
 xap.bridges.xap.ButtonBridge.prototype = new xap.bridges.xap.LabelBridge();

Modified: incubator/xap/trunk/src/xap/bridges/xap/CheckboxBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/xap/CheckboxBridge.js?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/xap/CheckboxBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/xap/CheckboxBridge.js Tue Oct 17 13:36:14 2006
@@ -16,14 +16,14 @@
  */
 
 Xap.provide("xap.bridges.xap.CheckboxBridge"); 
-Xap.require("xap.bridges.basic.AbstractBlackBoxWidgetBridge");
+Xap.require("xap.bridges.basic.AbstractWidgetBridge");
 Xap.require("xap.widgets.Checkbox");
 
 xap.bridges.xap.CheckboxBridge = function() {
-	xap.bridges.basic.AbstractBlackBoxWidgetBridge.call(this);
+	xap.bridges.basic.AbstractWidgetBridge.call(this);
 }
 
-Xap.setupClassAsSubclassOf("xap.bridges.xap.CheckboxBridge", "xap.bridges.basic.AbstractBlackBoxWidgetBridge");
+Xap.setupClassAsSubclassOf("xap.bridges.xap.CheckboxBridge", "xap.bridges.basic.AbstractWidgetBridge");
 
 
 xap.bridges.xap.CheckboxBridge.prototype = new xap.bridges.xap.LabelBridge();

Modified: incubator/xap/trunk/src/xap/bridges/xap/LabelBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/xap/LabelBridge.js?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/src/xap/bridges/xap/LabelBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/xap/LabelBridge.js Tue Oct 17 13:36:14 2006
@@ -16,14 +16,14 @@
  */
 
 Xap.provide("xap.bridges.xap.LabelBridge"); 
-Xap.require("xap.bridges.basic.AbstractBlackBoxWidgetBridge");
+Xap.require("xap.bridges.basic.AbstractWidgetBridge");
 Xap.require("xap.widgets.Label");
 
 xap.bridges.xap.LabelBridge = function() {
-	xap.bridges.basic.AbstractBlackBoxWidgetBridge.call(this);
+	xap.bridges.basic.AbstractWidgetBridge.call(this);
 }
 
-Xap.setupClassAsSubclassOf("xap.bridges.xap.LabelBridge", "xap.bridges.basic.AbstractBlackBoxWidgetBridge");
+Xap.setupClassAsSubclassOf("xap.bridges.xap.LabelBridge", "xap.bridges.basic.AbstractWidgetBridge");
 
 
 

Modified: incubator/xap/trunk/src/xap/util/allXapClassStrings.txt
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/util/allXapClassStrings.txt?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================
--- incubator/xap/trunk/src/xap/util/allXapClassStrings.txt (original)
+++ incubator/xap/trunk/src/xap/util/allXapClassStrings.txt Tue Oct 17 13:36:14 2006
@@ -1,4 +1,4 @@
-xap.bridges.basic.AbstractBlackBoxWidgetBridge
+xap.bridges.basic.AbstractWidgetBridge
 xap.bridges.basic.DomNodeBridge
 xap.bridges.basic.TextViewBridge
 xap.bridges.dojo.DojoButtonBridge
--- incubator/xap/trunk/src/xap/bridges/basic/DomNodeBridge.js (original)
+++ incubator/xap/trunk/src/xap/bridges/basic/DomNodeBridge.js Tue Oct 17 13:36:14 2006
@@ -16,7 +16,7 @@
  */
  
 Xap.provide("xap.bridges.basic.DomNodeBridge"); 
-Xap.require("xap.bridges.basic.AbstractBlackBoxWidgetBridge") ;
+Xap.require("xap.bridges.basic.AbstractWidgetBridge") ;
 /**
  * @fileoverview
  * 
@@ -35,7 +35,7 @@
  * @author mturyn
  */
 xap.bridges.basic.DomNodeBridge = function() {
-	xap.bridges.basic.AbstractBlackBoxWidgetBridge.call( this );
+	xap.bridges.basic.AbstractWidgetBridge.call( this );
 	if(arguments[0]){
 		this._peer = arguments[0] ;
 	}
@@ -43,7 +43,7 @@
 
 Xap.setupClassAsSubclassOf(
 	"xap.bridges.basic.DomNodeBridge",
-	"xap.bridges.basic.AbstractBlackBoxWidgetBridge"
+	"xap.bridges.basic.AbstractWidgetBridge"
 							);
 
 
@@ -182,7 +182,7 @@
 
 /**
  * Attribute setter method for 'x' designed to be triggered by
- * <code>xap.bridges.basic.AbstractBlackBoxWidgetBridge.setAttribute</code>
+ * <code>xap.bridges.basic.AbstractWidgetBridge.setAttribute</code>
  * after it's been found via that class' implementation of
  * <code>getSetterFunctionForAttribute</code>.
  * @param{string} value The new x-value for the new left edge of the component.
@@ -194,7 +194,7 @@
 
 /**
  * Attribute setter method for 'y' designed to be triggered by
- * <code>xap.bridges.basic.AbstractBlackBoxWidgetBridge.setAttribute</code>
+ * <code>xap.bridges.basic.AbstractWidgetBridge.setAttribute</code>
  * after it's been found via that class' implementation of
  * <code>getSetterFunctionForAttribute</code>.
  * @param{string} value The new y-value for the new top edge of the component.
@@ -256,7 +256,7 @@
 
 /**
  *  Since this just wraps a dom node peer, this function is simple here---return the peer.
  *  ---and because we haven't overwritten AbstractBlackBoxWidgetBridge,
  *  this.getDisplayDomNode == this.getRootDomeNode....
 **/
 xap.bridges.basic.DomNodeBridge.prototype.getRootDomNode = function(){
@@ -352,7 +352,7 @@
 
 /**
  * Attribute setter method for component width, designed to be triggered by
- * <code>xap.bridges.basic.AbstractBlackBoxWidgetBridge.setAttribute</code>
+ * <code>xap.bridges.basic.AbstractWidgetBridge.setAttribute</code>
  * after it's been found via that class' implementation of
  * <code>getSetterFunctionForAttribute</code>.
  * @param{string} value The new width value for the component.
@@ -364,7 +364,7 @@
 
 /**
  * Attribute setter method for component height, designed to be triggered by
- * <code>xap.bridges.basic.AbstractBlackBoxWidgetBridge.setAttribute</code>
+ * <code>xap.bridges.basic.AbstractWidgetBridge.setAttribute</code>
  * after it's been found via that class' implementation of
  * <code>getSetterFunctionForAttribute</code>.
  * @param{string} value The new height value for the component.
@@ -375,7 +375,7 @@
 
 /**
  * Attribute setter method for the component foreground color, designed to be triggered by
- * <code>xap.bridges.basic.AbstractBlackBoxWidgetBridge.setAttribute</code>
+ * <code>xap.bridges.basic.AbstractWidgetBridge.setAttribute</code>
  * after it's been found via that class' implementation of
  * <code>getSetterFunctionForAttribute</code>.
  * @param{string} value The new value for the component's foreground color.
@@ -387,7 +387,7 @@
 
 /**
  * Attribute setter method for the component's background's color, designed to be triggered by
- * <code>xap.bridges.basic.AbstractBlackBoxWidgetBridge.setAttribute</code>
+ * <code>xap.bridges.basic.AbstractWidgetBridge.setAttribute</code>
  * after it's been found via that class' implementation of
  * <code>getSetterFunctionForAttribute</code>.
  * @param{string} value The new value for the component background-color.
@@ -398,7 +398,7 @@
 
 /**
  * Attribute setter method for the node interior's vertical alignment, designed to be triggered by
- * <code>xap.bridges.basic.AbstractBlackBoxWidgetBridge.setAttribute</code>
+ * <code>xap.bridges.basic.AbstractWidgetBridge.setAttribute</code>
  * after it's been found via that class' implementation of
  * <code>getSetterFunctionForAttribute</code>.
  * @param{string} value The new value for the vertical alignment in force within the node.
@@ -409,7 +409,7 @@
 
 /**
  * Attribute setter method for the node's notional sheet in the page, designed to be triggered by
- * <code>xap.bridges.basic.AbstractBlackBoxWidgetBridge.setAttribute</code>
+ * <code>xap.bridges.basic.AbstractWidgetBridge.setAttribute</code>
  * after it's been found via that class' implementation of
  * <code>getSetterFunctionForAttribute</code>.
  * @param{string} value The new value for the value influencing when this node will
@@ -256,7 +256,7 @@
 /**
  *  Since this just wraps a dom node peer, this function is simple here---return the peer.
- *  ---and because we haven't overwritten AbstractBlackBoxWidgetBridge,
+ *  ---and because we haven't overwritten AbstractWidgetBridge,
  *  this.getDisplayDomNode == this.getRootDomeNode....
 **/

Modified: incubator/xap/trunk/src/xap/bridges/dojo/CellBridge.js
URL: http://svn.apache.org/viewvc/incubator/xap/trunk/src/xap/bridges/dojo/CellBridge.js?view=diff&rev=465032&r1=465031&r2=465032
==============================================================================